@@ -15,8 +15,8 @@
     under the License.
 */
 
-const path = require('path');
-const fs = require('fs-extra');
+const fs = require('node:fs');
+const path = require('node:path');
 const semver = require('semver');
 const fetch = require('cordova-fetch');
 const CordovaError = require('cordova-common').CordovaError;
@@ -58,7 +58,7 @@ function addHelper (cmd, hooksRunner, projectRoot, targets, opts) {
     // The "platforms" dir is safe to delete, it's almost equivalent to
     // cordova platform rm <list of all platforms>
     const platformsDir = path.join(projectRoot, 'platforms');
-    fs.ensureDirSync(platformsDir);
+    fs.mkdirSync(platformsDir, { recursive: true });
 
     return hooksRunner.fire('before_platform_' + cmd, opts)
         .then(function () {
@@ -98,12 +98,6 @@ function addHelper (cmd, hooksRunner, projectRoot, targets, opts) {
                         spec = module.exports.getVersionFromConfigFile(platform, cfg);
                     }
 
-                    // If spec still doesn't exist, grab latest released version from the npmjs registry
-                    if (!spec) {
-                        events.emit('verbose', 'Grabbing the latest released version from the npmjs registry.');
-                        spec = 'latest';
-                    }
-
                     // Handle local paths
                     if (spec) {
                         const maybeDir = cordova_util.fixRelativePath(spec);
@@ -138,11 +132,9 @@ function addHelper (cmd, hooksRunner, projectRoot, targets, opts) {
                         }
                     }
 
-                    if (/-nightly|-dev$/.exec(platDetails.version)) {
-                        msg = 'Warning: using prerelease platform ' + platform +
-                              '@' + platDetails.version +
-                              '.\nUse \'cordova platform add ' +
-                              platform + '@latest\' to add the latest published version instead.';
+                    if (semver.prerelease(platDetails.version)) {
+                        msg = `Warning: using prerelease platform ${platform}@${platDetails.version}.`;
+                        msg += `\nUse 'cordova platform add ${platform}@latest to add the latest published version instead.`;
                         events.emit('warn', msg);
                     }
 
@@ -297,13 +289,22 @@ function installPluginsForNewPlatform (platform, projectRoot, opts) {
     // Get a list of all currently installed plugins, ignoring those that have already been installed for this platform
     // during prepare (installed from config.xml).
     const platformJson = PlatformJson.load(plugins_dir, platform);
-    const plugins = cordova_util.findPlugins(plugins_dir).filter(function (plugin) {
+    let plugins = cordova_util.findPlugins(plugins_dir).filter(function (plugin) {
         return !platformJson.isPluginInstalled(plugin);
     });
     if (plugins.length === 0) {
         return Promise.resolve();
     }
 
+    // If package.json includes the plugins, we use that for proper sort order
+    const pkgJson = readPackageJsonIfExists(projectRoot);
+    if (pkgJson?.cordova?.plugins) {
+        const pkgPluginIDs = Object.keys(pkgJson.cordova.plugins);
+        plugins = plugins.sort(function (a, b) {
+            return pkgPluginIDs.indexOf(a) - pkgPluginIDs.indexOf(b);
+        });
+    }
+
     const output = path.join(projectRoot, 'platforms', platform);
     const plugman = require('../../plugman/plugman');
     const fetchMetadata = require('../../plugman/util/metadata');
